@@ -4,16 +4,18 @@ from typing import AnyStr, Callable, List, Optional, Set, Type, TypeVar, cast
 
 from aioredis.abc import AbcConnection
 from aioredis.commands import Redis
+from aioredis.util import _NOTSET
 
 from aioredis_cluster.abc import AbcCluster
 
 from .cluster import ClusterCommandsMixin
 
 
-__all__ = [
+__all__ = (
+    "Redis",
     "RedisCluster",
     "conn_is_cluster",
-]
+)
 
 _T = TypeVar("_T")
 
@@ -51,7 +53,7 @@ class RedisCluster(ClusterCommandsMixin, Redis):
         return await self.connection.keys_master(key, *keys)
 
     # special behavior for commands
-    async def randomkey(self) -> Optional[bytes]:
+    async def randomkey(self, *, encoding=_NOTSET) -> Optional[bytes]:
         if not conn_is_cluster(self.connection):
             return await super().randomkey()
 
@@ -63,6 +65,12 @@ class RedisCluster(ClusterCommandsMixin, Redis):
 
         return None
 
+    @property
+    def cluster_connection(self) -> AbcCluster:
+        self._only_for_cluster()
+
+        return cast(AbcCluster, self.connection)
+
     def _only_for_cluster(self):
         if not conn_is_cluster(self.connection):
             raise RuntimeError("Connection is not a Cluster instance")
